Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(323)

Unified Diff: remoting/host/desktop_process_unittest.cc

Issue 455073004: Switch DesktopEnvironment to return a DesktopCapturer. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Remove ShapedDesktopCapturer::Create() Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/host/desktop_environment.h ('k') | remoting/host/desktop_session_agent.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/desktop_process_unittest.cc
diff --git a/remoting/host/desktop_process_unittest.cc b/remoting/host/desktop_process_unittest.cc
index 55e547d096b67e0695f73bd0fc58c26044381574..7a188a8b50e2af3bf86f1d0a59fb9ff0a018d489 100644
--- a/remoting/host/desktop_process_unittest.cc
+++ b/remoting/host/desktop_process_unittest.cc
@@ -19,7 +19,7 @@
#include "remoting/base/auto_thread_task_runner.h"
#include "remoting/host/chromoting_messages.h"
#include "remoting/host/desktop_process.h"
-#include "remoting/host/fake_screen_capturer.h"
+#include "remoting/host/fake_desktop_capturer.h"
#include "remoting/host/host_exit_codes.h"
#include "remoting/host/host_mock_objects.h"
#include "remoting/host/screen_resolution.h"
@@ -105,7 +105,7 @@ class DesktopProcessTest : public testing::Test {
void ConnectNetworkChannel(IPC::PlatformFileForTransit desktop_process);
void OnDesktopAttached(IPC::PlatformFileForTransit desktop_process);
// Creates a DesktopEnvironment with a fake webrtc::ScreenCapturer, to mock
// DesktopEnvironmentFactory::Create().
DesktopEnvironment* CreateDesktopEnvironment();
@@ -113,9 +113,9 @@ class DesktopProcessTest : public testing::Test {
// DesktopEnvironment::CreateInputInjector().
InputInjector* CreateInputInjector();
// Creates a fake webrtc::ScreenCapturer, to mock
// DesktopEnvironment::CreateVideoCapturer().
- webrtc::ScreenCapturer* CreateVideoCapturer();
+ webrtc::DesktopCapturer* CreateVideoCapturer();
// Disconnects the daemon-to-desktop channel causing the desktop process to
// exit.
@@ -218,8 +218,8 @@ InputInjector* DesktopProcessTest::CreateInputInjector() {
return input_injector;
}
-webrtc::ScreenCapturer* DesktopProcessTest::CreateVideoCapturer() {
- return new FakeScreenCapturer();
+webrtc::DesktopCapturer* DesktopProcessTest::CreateVideoCapturer() {
+ return new FakeDesktopCapturer();
}
void DesktopProcessTest::DisconnectChannels() {
« no previous file with comments | « remoting/host/desktop_environment.h ('k') | remoting/host/desktop_session_agent.h » ('j') | no next file with comments »
@@ -105,7 +105,7 @@ class DesktopProcessTest : public testing::Test {
void ConnectNetworkChannel(IPC::PlatformFileForTransit desktop_process);
void OnDesktopAttached(IPC::PlatformFileForTransit desktop_process);
- // Creates a DesktopEnvironment with a fake webrtc::ScreenCapturer, to mock
+ // Creates a DesktopEnvironment with a fake webrtc::DesktopCapturer, to mock
// DesktopEnvironmentFactory::Create().
DesktopEnvironment* CreateDesktopEnvironment();
@@ -113,9 +113,9 @@ class DesktopProcessTest : public testing::Test {
// DesktopEnvironment::CreateInputInjector().
InputInjector* CreateInputInjector();
- // Creates a fake webrtc::ScreenCapturer, to mock
+ // Creates a fake webrtc::DesktopCapturer, to mock
// DesktopEnvironment::CreateVideoCapturer().

Powered by Google App Engine
This is Rietveld 408576698